<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Abdocken</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Dock</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Beenden erzwingen</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Alle schließen</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation type="unfinished">Öffnen</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation type="unfinished">Abdocken</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation type="unfinished">Dock</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation type="unfinished">Beenden erzwingen</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation type="unfinished">Alle schließen</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
